==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_powerroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function CannotEscape()
    PRI()
    TUR()MS4("\nCannot escape!")NOD()
end

function CannotCheck()
    PRI()
    TUR()MS4("\nNow is not the time for that!")NOD()
end

--去外面
function Door_GoPath()
    if(FLJ("InBossFight")) then
        CannotEscape()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPath",0,1)FAO(3)TRA("CS_path","E0091",177,20)
    end
end
--电源开关
function PowerSwitch()
    if(FLJ("InBossFight")) then
        CannotCheck()
    elseif(FLJ("PowerOn")) then
        KEY()
        TUR()MS4("\nPower is operating normally.")NOD()
    else
        KEY()
        MS4("Fan power is OFF.")NOD()
        CAT("\nMalco's power is OFF.")NOD()CLR()
        CAT("\nActivate the power?")YNJ()CLO()
        if(YES()) then
            WAI(32)
            SOU("CS_043_computer_beep")
            FLP("PowerOn")
            FLP("JellyAppear")
            SNP("CS_powerroom_screen",23,14,0,"mainLayer","")
            SNP("CS_powerroom_wave",23,12,0,"mainLayer","")
            WAI(32)
            MS4("\nPower activated.")NOD()CLO()
            ANP("Malco1",10,1)WAI(20)AMC(0,0,PLY())SLR(0,PLY())WAI(450)
            CMU("CS_Gravity")
            MS4("Intruder detected!!")NOD()
            CAT("\nEliminate intruder immediately!!")NOD()WAI(50)
            CNP("MalcoBoss","CS_boss_malco",0,1)
            MNP("MalcoBoss","Malco1")
            BSL("MalcoBoss")
            DNP("Malco1")
            FLP("InBossFight")
        end
    end
end
--调查马鲁可
function Malco1()
    KEY()
    MS4("\nA powered-off robot.")NOD()
end

--战胜马鲁可后
function MalcoBoss()
    KEY()
    CNP("MalcoBoss","CS_malco_animate",0,1)
    ANP("MalcoBoss",200)
    WAI(60)
    CMU("CS_Fanfale3")
    MS4("\nDefeated Malco!")WAI(140)NOD()
    CMU("CS_Vivi")
    FLS("InBossFight")
end

==> ocstore25_7_23.zip: OcStore/Prgm/data/language/en-us/script/CS_powerroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function CannotEscape()
    PRI()
    TUR()MS4("\nCannot escape!")NOD()
end

function CannotCheck()
    PRI()
    TUR()MS4("\nNow is not the time for that!")NOD()
end

--去外面
function Door_GoPath()
    if(FLJ("InBossFight")) then
        CannotEscape()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPath",0,1)FAO(3)TRA("CS_path","E0091",177,20)
    end
end
--电源开关
function PowerSwitch()
    if(FLJ("InBossFight")) then
        CannotCheck()
    elseif(FLJ("PowerOn")) then
        KEY()
        TUR()MS4("\nPower is operating normally.")NOD()
    else
        KEY()
        MS4("Fan power is OFF.")NOD()
        CAT("\nMalco's power is OFF.")NOD()CLR()
        CAT("\nActivate the power?")YNJ()CLO()
        if(YES()) then
            WAI(32)
            SOU("CS_043_computer_beep")
            FLP("PowerOn")
            FLP("JellyAppear")
            SNP("CS_powerroom_screen",23,14,0,"mainLayer","")
            SNP("CS_powerroom_wave",23,12,0,"mainLayer","")
            WAI(32)
            MS4("\nPower activated.")NOD()CLO()
            ANP("Malco1",10,1)WAI(20)AMC(0,0,PLY())SLR(0,PLY())WAI(450)
            CMU("CS_Gravity")
            MS4("Intruder detected!!")NOD()
            CAT("\nEliminate intruder immediately!!")NOD()WAI(50)
            CNP("MalcoBoss","CS_boss_malco",0,1)
            MNP("MalcoBoss","Malco1")
            BSL("MalcoBoss")
            DNP("Malco1")
            FLP("InBossFight")
            SKP("QuickMalcoBoss")
        end
    end
end
--调查马鲁可
function Malco1()
    KEY()
    MS4("\nA powered-off robot.")NOD()
end

--战胜马鲁可后
function MalcoBoss()
    KEY()
    CNP("MalcoBoss","CS_malco_animate",0,1)
    ANP("MalcoBoss",200)
    WAI(60)
    CMU("CS_Fanfale3")
    MS4("\nDefeated Malco!")WAI(140)NOD()
    CMU("CS_Vivi")
    FLS("InBossFight")
    SKS("QuickMalcoBoss")
end

function QuickMalcoBoss()
    PRI()
    FLP("PowerOn")
    FLP("JellyAppear")
    SNP("CS_powerroom_screen",23,14,0,"mainLayer","")
    SNP("CS_powerroom_wave",23,12,0,"mainLayer","")
    ANP("Malco1",10,1)AMC(0,0,PLY())SLR(0,PLY())
    FAI(1)
    KEY()
    CMU("CS_Gravity")
    CNP("MalcoBoss","CS_boss_malco",0,1)
    MNP("MalcoBoss","Malco1")
    BSL("MalcoBoss")
    DNP("Malco1")
    FLP("InBossFight")
end
